@@ -6,7 +6,7 @@ from unittest.mock import MagicMock
 
 import pytest
 
-from xonsh.aliases import make_default_aliases, source_alias
+from xonsh.aliases import make_default_aliases, source_alias_fn
 
 
 @pytest.fixture
@@ -29,19 +29,39 @@ def mocked_execx_checker(xession, monkeypatch):
     return checker
 
 
-def test_source_current_dir(mockopen, monkeypatch, mocked_execx_checker):
+def test_source_files(mockopen, monkeypatch, mocked_execx_checker):
     monkeypatch.setattr(os.path, "isfile", lambda x: True)
-    source_alias(["foo", "bar"])
-    assert mocked_execx_checker == ["foo", "bar"]
+    files = [".xonshrc", "foo.xsh", "bar.xonshrc", "py.py"]
+    source_alias_fn(files)
+    assert mocked_execx_checker == files
 
 
-def test_source_path(mockopen, mocked_execx_checker, xession):
+def test_source_files_any_ext_exception(mockopen, monkeypatch, mocked_execx_checker):
+    monkeypatch.setattr(os.path, "isfile", lambda x: True)
+    with pytest.raises(RuntimeError):
+        source_alias_fn(["foo.bar", "bar.foo", ".foobar"])
+
+
+def test_source_files_any_ext(mockopen, monkeypatch, mocked_execx_checker):
+    monkeypatch.setattr(os.path, "isfile", lambda x: True)
+    files = [
+        "foo.bar",
+        "bar.foo",
+        ".foobar",
+        ".xonshrc",
+        "foo.xsh",
+        "bar.xonshrc",
+        "py.py",
+    ]
+    source_alias_fn(files, ignore_ext=True)
+    assert mocked_execx_checker == files
+
+
+def test_source_from_env_path(mockopen, mocked_execx_checker, xession):
     with xession.env.swap(PATH=[Path(__file__).parent.parent / "bin"]):
-        source_alias(["foo", "bar"])
-    path_foo = os.path.join("bin", "foo")
-    path_bar = os.path.join("bin", "bar")
-    assert mocked_execx_checker[0].endswith(path_foo)
-    assert mocked_execx_checker[1].endswith(path_bar)
+        source_alias_fn(["foo", "bar"], ignore_ext=True)
+    assert mocked_execx_checker[0].endswith("foo")
+    assert mocked_execx_checker[1].endswith("bar")
 
 
 @pytest.mark.parametrize(
