@@ -130,6 +130,66 @@ def XONSH_TOKENS():
     return set(XONSH_EXPR_TOKENS) | set(XONSH_STMT_TOKENS)
 
 
+@xl.lazyobject
+def RE_XONSH_IMP():
+    """Regex pattern to match __xonsh__.imp.<module> syntax."""
+    return re.compile(r"(__xonsh__|@)\.imp\.([a-zA-Z_][\w\.]*)?$")
+
+
+@contextual_completer
+def complete_xonsh_imp(context: CompletionContext) -> CompleterResult:
+    """
+    Completes module names for the inline xonsh importer (__xonsh__.imp.<module>).
+    """
+    if context.python is None:
+        return None
+
+    line = context.python.multiline_code
+    prefix = (line.rsplit(maxsplit=1) or [""])[-1]
+
+    # Check if we're completing __xonsh__.imp.<module>
+    m = RE_XONSH_IMP.search(prefix)
+    if m is None:
+        return None
+
+    xsh = m.group(1)
+    module_path = m.group(2) or ""
+
+    # Import the necessary functions from the imports completer
+    from xonsh.completers.imports import (
+        filter_completions,
+        get_root_modules,
+        try_import,
+    )
+
+    # Handle nested module paths (e.g., os.path)
+    if "." in module_path:
+        # Split into base module and submodule path
+        parts = module_path.split(".")
+        base_module = ".".join(parts[:-1])
+        prefix_part = parts[-1]
+
+        # Try to get completions for the submodule
+        try:
+            submodule_completions = try_import(base_module, only_modules=True)
+            full_prefix = f"{xsh}.imp.{base_module}."
+            completions = {
+                full_prefix + comp
+                for comp in filter_completions(prefix_part, submodule_completions)
+            }
+            return completions, len(prefix)
+        except Exception:
+            return None
+    else:
+        # Complete root-level module names
+        modules = get_root_modules()
+        full_prefix = f"{xsh}.imp."
+        completions = {
+            full_prefix + mod for mod in filter_completions(module_path, modules)
+        }
+        return completions, len(prefix)
+
+
 @contextual_completer
 def complete_python(context: CompletionContext) -> CompleterResult:
     """
@@ -246,17 +306,33 @@ def attr_complete(prefix, ctx, filter_func):
         a = getattr(val, opt)
         if XSH.env["COMPLETIONS_BRACKETS"]:
             if callable(a):
-                rpl = opt + "("
-            elif isinstance(a, (cabc.Sequence, cabc.Mapping)):
+                # Determine if this callable has useful attributes (class/module/namespace)
+                has_useful_attrs = (
+                    inspect.isclass(a)
+                    or inspect.ismodule(a)
+                    or any(not attr.startswith("_") for attr in dir(a))
+                )
+
+                base_comp = prefix[: prelen - len(attr)] + opt
+
+                if has_useful_attrs:
+                    # Show plain name for attribute access (e.g., classes, modules)
+                    attrs.add(base_comp)
+                else:
+                    # Show with ( for calling (e.g., simple functions, methods)
+                    attrs.add(base_comp + "(")
+            elif isinstance(a, cabc.Sequence | cabc.Mapping):
                 rpl = opt + "["
+                comp = prefix[: prelen - len(attr)] + rpl
+                attrs.add(comp)
             else:
                 rpl = opt
+                comp = prefix[: prelen - len(attr)] + rpl
+                attrs.add(comp)
         else:
             rpl = opt
-        # note that prefix[:prelen-len(attr)] != prefix[:-len(attr)]
-        # when len(attr) == 0.
-        comp = prefix[: prelen - len(attr)] + rpl
-        attrs.add(comp)
+            comp = prefix[: prelen - len(attr)] + rpl
+            attrs.add(comp)
     return attrs
 
 
