@@ -1,9 +1,10 @@
 """Implements helper class for parsing Xonsh syntax within f-strings."""
+
 import re
 from ast import parse as pyparse
 
-from xonsh import ast
-from xonsh.lazyasd import lazyobject
+from xonsh.lib.lazyasd import lazyobject
+from xonsh.parsers import ast
 from xonsh.platform import PYTHON_VERSION_INFO
 
 
